[evolution-data-server/email-factory] Create Sent/Drafts for pop.



commit a11c8ae7ef3f77707f474a7b064f63125aa73565
Author: Srinivasa Ragavan <srini linux intel com>
Date:   Wed Jun 29 02:46:24 2011 +0300

    Create Sent/Drafts for pop.

 mail/daemon/mail-ops.c |   10 +++++++++-
 1 files changed, 9 insertions(+), 1 deletions(-)
---
diff --git a/mail/daemon/mail-ops.c b/mail/daemon/mail-ops.c
index fbc53a5..d0c6ba8 100644
--- a/mail/daemon/mail-ops.c
+++ b/mail/daemon/mail-ops.c
@@ -330,7 +330,7 @@ fetch_pop3_folder (const char *uri)
 
 	destination = camel_store_get_folder (local, folder_name, 0, NULL);
 	if (!destination) {
 		/* If its first time, create that folder. */
 		CamelFolderInfo *info;
 
 		info = camel_store_create_folder (local, NULL, folder_name, NULL);
@@ -338,6 +338,14 @@ fetch_pop3_folder (const char *uri)
 			g_warning ("Unable to create POP3 folder: %s\n", folder_name);
 		else {
 			destination = camel_store_get_folder (local, folder_name, 0, NULL);
+			g_free (folder_name);
+			folder_name = g_strdup_printf ("%s/Drafts", email);
+
+			info = camel_store_create_folder (local, NULL, folder_name, NULL);
+			g_free (folder_name);
+			folder_name = g_strdup_printf ("%s/Sent", email);
+	
+			info = camel_store_create_folder (local, NULL, folder_name, NULL);
 		}
 	}
 	g_free (folder_name);
@@ -330,7 +330,7 @@ fetch_pop3_folder (const char *uri)
 	destination = camel_store_get_folder (local, folder_name, 0, NULL);
 	if (!destination) {
-		/* If its first time, create that folder. */
+		/* If its first time, create that folder & Draft/Sent. */
 		CamelFolderInfo *info;
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]